LandingTopsheet class

A custom topsheet widget for the app's authentication screens.

Displays an app title, tagline, and an image in a curved container.

Inheritance

Constructors

LandingTopsheet({Key? key, required String title, required String tagline, required String imagePath, bool isSvg = true, Color? backgroundColor})
const

Properties

backgroundColor Color?
Optional color for the background. If not provided, uses the theme's secondary color.
final
hashCode int
The hash code for this object.
no setterinherited
imagePath String
The path to the image asset (SVG or PNG).
final
isSvg bool
Whether the image is an SVG. If false, assumes it's a PNG or other regular image format.
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tagline String
The tagline or subtitle text to be displayed.
final
title String
The title of the app to be displayed.
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited